bayespy.inference.vmp.nodes.dirichlet.DirichletMoments.compute_fixed_moments
============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.dirichlet

.. automethod:: DirichletMoments.compute_fixed_moments